@@ -1,12 +1,12 @@
+from unit.utils.configuration import Configuration
 from unit.api.base_resource import BaseResource
 from unit.models.dispute import *
 from unit.models.codecs import DtoDecoder
 
 
 class DisputeResource(BaseResource):
-    def __init__(self, api_url, token, retries):
-        super().__init__(api_url, token, retries)
-        self.resource = "disputes"
+    def __init__(self, configuration: Configuration):
+        super().__init__("disputes", configuration)
 
     def get(self, dispute_id: str) -> Union[UnitResponse[DisputeDTO], UnitError]:
         response = super().get(f"{self.resource}/{dispute_id}")
