@@ -120,6 +120,9 @@ class UnitRequest(object):
             }
         }
 
+        if hasattr(self, 'relationships') and self.relationships:
+            payload["data"]["relationships"] = self.relationships
+
         if relationships:
             payload["data"]["relationships"] = relationships
 
@@ -418,6 +421,26 @@ class Merchant(UnitDTO):
         return None
 
 
+class HealthcareAmounts(UnitDTO):
+    def __init__(self, dental_amount: int, transit_amount: int, vision_optical_amount: int, prescription_rx_amount: int,
+                 clinic_other_qualified_medical_amount: int, total_healthcare_amount: int):
+        self.dental_amount = dental_amount
+        self.transit_amount = transit_amount
+        self.vision_optical_amount = vision_optical_amount
+        self.prescription_rx_amount = prescription_rx_amount
+        self.clinic_other_qualified_medical_amount = clinic_other_qualified_medical_amount
+        self.total_healthcare_amount = total_healthcare_amount
+
+    @staticmethod
+    def from_json_api(data: Dict):
+        if data:
+            return HealthcareAmounts(data.get("dentalAmount"), data.get("transitAmount"),
+                                     data.get("visionOpticalAmount"), data.get("prescriptionRXAmount"),
+                                     data.get("clinicOtherQualifiedMedicalAmount"), data.get("totalHealthcareAmount"))
+
+        return None
+
+
 class CardLevelLimits(UnitDTO):
     def __init__(self, daily_withdrawal: int, daily_purchase: int, monthly_withdrawal: int, monthly_purchase: int):
         self.daily_withdrawal = daily_withdrawal
@@ -638,3 +661,7 @@ class RichMerchantData(UnitDTO):
                                 RichMerchantDataCategory.from_json_api(data.get("categories")), data.get("address"),
                                 Coordinates.from_json_api(data.get("coordinates")),
                                 RichMerchantDataFacilitator.from_json_api(data.get("facilitators")))
+
+
+Tags = Optional[Dict[str, str]]
+
