@@ -19,3 +19,10 @@ def to_date(d: str):
 
 def to_date_str(d: date):
     return d.strftime("%Y-%m-%d")
+
+
+def to_year_str(d: date):
+    if type(d) is not date:
+        return None
+
+    return d.strftime("%Y")
\ No newline at end of file
